frac_complete: Demand minimal fraction of complete records
Description
Demand minimal fraction of complete records
Usage
frac_complete(r, vars = TRUE)
Value
a function that accepts a data frame and returns TRUE when the
fraction of complete records is larger than or equal to n and
otherwise FALSE.
Arguments
r
Minimal fraction of records that must be complete.
vars
[TRUE|column index] Column index into the data to
be tested (e.g. a character vectod with variable names or
a numeric vector with column positions). The indexed columns
will be testsed for completeness (absence of NA). Be default
vars=TRUE meaning that all columns are taken into account.