Learn R Programming

accumulate (version 1.0.0)

min_records: Demand minimal number of records

Description

Demand minimal number of records

Usage

min_records(n)

Value

a function that accepts a data frame and returns TRUE

when the number of records is larger than or equal to n

and otherwise FALSE.

Arguments

n

Minimal number of records in a group.

See Also

Other helpers: frac_complete(), min_complete()

Examples

Run this code

min_records(5)(women)
min_records(200)(women)

Run the code above in your browser using DataLab