powered by
Demand minimal number of records
min_records(n)
a function that accepts a data frame and returns TRUE
TRUE
when the number of records is larger than or equal to n
n
and otherwise FALSE.
FALSE
Minimal number of records in a group.
Other helpers: frac_complete(), min_complete()
frac_complete()
min_complete()
min_records(5)(women) min_records(200)(women)
Run the code above in your browser using DataLab